<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// S
	'safehtml_description' => 'Protezione del forum contro gli attacchi di tipo cross-site scripting',
	'safehtml_slogan' => 'Protezione del forum contro gli attacchi di tipo cross-site scripting',
];
